/**
 * @file
 *
 * Declarations for task queue.  This is inspired by the ``bounded
 * partial queue'' in Maurice Herlihy's book (Chapter 10.2).
 *
 * @author Jens Teubner <jens.teubner@cs.tu-dortmund.de>
 *
 * $Id$
 */

#include "config.h"

#include <pthread.h>

#include <stdbool.h>

struct task_queue_t {

    pthread_mutex_t  enqLock;
    pthread_mutex_t  deqLock;

    pthread_cond_t   notEmptyCondition;
    pthread_cond_t   notFullCondition;

    volatile unsigned int     head;
    volatile unsigned int     tail;

    unsigned int     capacity;     /**< capacity in number of entries */

    bool             terminateOnEmpty;

    volatile void           **entries;
};

typedef struct task_queue_t task_queue_t;

task_queue_t * task_queue_init (const unsigned int capacity);

void task_queue_enq (task_queue_t *queue, void *x);
void * task_queue_deq (task_queue_t *queue);
void * task_queue_trydeq (task_queue_t *queue);
